Learn R Programming

Hmisc (version 5.3-0)

binconf: Confidence Intervals for Binomial Probabilities

Description

Produces 1-alpha confidence intervals for binomial probabilities.

Usage

binconf(x, n, alpha=0.05,
        method=c("wilson","exact","asymptotic","all"),
        include.x=FALSE, include.n=FALSE, return.df=FALSE)

Arguments

Value

a matrix or data.frame containing the computed intervals and, optionally, x and n.

References

A. Agresti and B.A. Coull, Approximate is better than "exact" for interval estimation of binomial proportions, American Statistician, 52:119--126, 1998.

R.G. Newcombe, Logit confidence intervals and the inverse sinh transformation, American Statistician, 55:200--202, 2001.

L.D. Brown, T.T. Cai and A. DasGupta, Interval estimation for a binomial proportion (with discussion), Statistical Science, 16:101--133, 2001.

Examples

Run this code
binconf(0:10,10,include.x=TRUE,include.n=TRUE)
binconf(46,50,method="all")

Run the code above in your browser using DataLab