powered by
Capitalizes the first letter of each element of the string vector.
capitalize(string)
Returns a vector of charaters with the first letter capitalized
capitalize(c("Hello", "bob", "daN"))
Run the code above in your browser using DataLab