Learn R Programming

Hmisc (version 5.3-0)

plotp: Generic Method for Making Plotly Graphics

Description

plotp is a generic function that dispatches to plotp methods to make plotly graphics.

Usage

plotp(data, ...)

Value

typically a plotly object, as produced by the dispatched method

Arguments

data

an object having a plotp method

...

additional arguments passed to the specific plotp method