rcorr Computes a matrix of Pearson's r or Spearman's
rho rank correlation coefficients for all possible pairs of
columns of a matrix. Missing values are deleted in pairs rather than
deleting all rows of x having any missing variables. Ranks are
computed using efficient algorithms (see reference 2), using midranks
for ties.
Usage
rcorr(x, y, type=c("pearson","spearman"))
# S3 method for rcorr
print(x, ...)
Arguments
Value
rcorr returns a list with elements r, the
matrix of correlations, n the
matrix of number of observations used in analyzing each pair of variables,
P, the asymptotic P-values, and type.
Pairs with fewer than 2 non-missing values have the r values set to NA.
The diagonals of n are the number of non-NAs for the single variable
corresponding to that row and column.
Details
Uses midranks in case of ties, as described by Hollander and Wolfe.
P-values are approximated by using the t or F distributions.
References
Hollander M. and Wolfe D.A. (1973). Nonparametric Statistical Methods.
New York: Wiley.
Press WH, Flannery BP, Teukolsky SA, Vetterling, WT (1988): Numerical
Recipes in C. Cambridge: Cambridge University Press.