if (FALSE) {
dat <- csv.get('myfile.csv')
# Read a csv file with junk in the first row, variable names in the
# second, long variable labels in the third, and junk in the 4th row
dat <- csv.get('myfile.csv', vnames=2, labels=3, skip=4)
}
Run the code above in your browser using DataLab