powered by
plotp is a generic function that dispatches to plotp methods to make plotly graphics.
plotp
plotly
plotp(data, ...)
typically a plotly object, as produced by the dispatched method
an object having a plotp method
additional arguments passed to the specific plotp method