stata.get invokes the read.dta function in the
foreign package to read an STATA file, with a default output
format of data.frame. The label function is used to
attach labels to individual variables instead of to the data frame as
done by read.dta. By default, integer-valued variables are
converted to a storage mode of integer unless
force.single=FALSE. Date variables are converted to RDate variables. By default, underscores in names are converted to periods.