tex is a little function to save typing when including TeX
commands in graphs that are used with the psfrag package in LaTeX to
typeset any LaTeX text inside a postscript graphic. tex
surrounds the input character string with \tex[options]{}.
This is especially useful for getting Greek letters and math symbols
in postscript graphs. By default tex returns a string with
psfrag commands specifying that the string be centered, not
rotated, and not specially enlarged or shrunk.
tex(string, lref='c', psref='c', scale=1, srt=0)tex returns a modified character string.
Grant MC, Carlisle (1998): The PSfrag System, Version 3. Full
documentation is obtained by searching www.ctan.org for pfgguide.ps.
postscript, par, ps.options,
mgp.axis.labels, pdf,
trellis.device, setTrellis