Compute mean x vs. a function of y (e.g. median) by quantile
groups of x or by x grouped to have a given minimum number of
observations. Deletes NAs in x and y before doing computations.
Usage
xy.group(x, y, m=150, g, fun=mean, result="list")
Arguments
Value
if result="list", a list with components x and y suitable for plotting.
if result="matrix", matrix with rows corresponding to x-groups and columns named
n, x, and y.